@@ -1,15 +1,16 @@
-/* MEP_interpolation.c -- This file is part of GNU/Archimedes 0.0.3
-   This code is a simulator for Submicron 2D Silicon/GaAs
+/* MEP_interpolation.c -- This file is part of GNU/Archimedes 0.1.0
+   This code is a simulator for Submicron 2D III-V semiconductor
    Devices. It implements the Monte Carlo method and MEP model
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
-   of effective potential method.
+   of effective potential method. It is now able to simulate applied
+   magnetic fields along with self consistent Faraday equation.
 
    Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -18,16 +19,13 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
-   USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 
 
 // =================================================================
-// File Name : MEP_interpolation.c
-// Version   : release 0.0.3
 // Date of Creation : 05 May 2004, Siracusa, Italy, Jean Michel Sellier
-// Last Revision : 10 Aug.2007, Siracusa, Italy, Jean Michel Sellier.
+// Last Revision : 09 Sep.2007, Siracusa, Italy, Jean Michel Sellier.
 // System of Measure : M.K.S.C. System
 // =================================================================
 
@@ -197,7 +195,7 @@ Ui(real t)
 // *******************************
 
 real
-Fi(real t,real mstar)
+Fi(real t)
 {
 // Non-parabolic MEP flux of the energy flux
 // 05 May 2004, Siracusa, J.M. Sellier
@@ -205,20 +203,20 @@ Fi(real t,real mstar)
 // output : F in (Joule^2)/kg
  real W=t/Q; // energy in eV
  return(f[1]*pow(W,5.)+f[2]*pow(W,4.)
-	 +f[3]*pow(W,3.)+f[4]*pow(W,2.)+f[5]*W+f[6])*Q*Q/mstar; 
+	 +f[3]*pow(W,3.)+f[4]*pow(W,2.)+f[5]*W+f[6])*Q*Q/MSTAR[SILICON][1]; 
 }
 
 // ********************************
 
 real
-Gi(real t, real mstar)
+Gi(real t)
 {
 // 05 May 2004, Siracusa, J.M. Sellier
 // input : energy in Joule
 // output : G in Joule/kg
  real W=t/Q; // energy in eV
  return(g[1]*pow(W,5.)+g[2]*pow(W,4.)
-	 +g[3]*pow(W,3.)+g[4]*pow(W,2.)+g[5]*W+g[6])*Q/mstar;
+	 +g[3]*pow(W,3.)+g[4]*pow(W,2.)+g[5]*W+g[6])*Q/MSTAR[SILICON][1];
 }
 
 // *********************************
